@@ -1,6 +1,7 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2016,2017,2018,2019,2020,2021 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2016,2017,2018,2019,2020,2021,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2022 Timothy Sample <samplet@ngyro.com>
  *
  * This file is part of GNU Mes.
  *
@@ -34,7 +35,7 @@ struct scm
     char *bytes;
     long length;
     struct scm *ref;
-    struct scm *variable;
+    struct scm *binding;
     struct scm *macro;
     long port;
   };
@@ -50,6 +51,7 @@ struct scm
     long value;
     FUNCTION function;
     struct scm *vector;
+    long lexical_p; /* for bindings */
   };
 };
 
@@ -79,8 +81,10 @@ extern struct scm *R1;
 extern struct scm *R2;
 /* continuation */
 extern struct scm *R3;
-/* current-module */
+/* initial module obarray */
 extern struct scm *M0;
+/* current module */
+extern struct scm *M1;
 /* macro */
 extern struct scm *g_macros;
 extern struct scm *g_ports;
@@ -109,6 +113,7 @@ extern struct timespec *gc_end_time;
 extern size_t gc_time;
 
 extern char **__execl_c_argv;
+extern char **__execle_c_env;
 extern char *__open_boot_buf;
 extern char *__open_boot_file_name;
 extern char *__setenv_buf;
@@ -116,6 +121,10 @@ extern char *__reader_read_char_buf;
 extern struct timespec *g_start_time;
 extern struct timeval *__gettimeofday_time;
 extern struct timespec *__get_internal_run_time_ts;
+extern struct utsname *__uts;
+
+extern struct scm *scm_hash_table_type;
+extern struct scm *scm_variable_type;
 
 struct scm *cast_charp_to_scmp (char const *i);
 struct scm **cast_charp_to_scmpp (char const *i);
@@ -134,18 +143,25 @@ struct scm *builtin_name (struct scm *builtin);
 struct scm *cstring_to_list (char const *s);
 struct scm *cstring_to_symbol (char const *s);
 struct scm *cell_ref (struct scm *cell, long index);
+struct scm *current_module_variable (struct scm *name, struct scm *define_p);
+struct scm *standard_eval_closure (struct scm *name, struct scm *define_p);
+struct scm *standard_interface_eval_closure (struct scm *name, struct scm *define_p);
+struct scm *module_make_local_var_x (struct scm *module, struct scm *name);
+struct scm *module_variable (struct scm *module, struct scm *name);
 struct scm *fdisplay_ (struct scm *, int, int);
 struct scm *init_symbols ();
 struct scm *init_time (struct scm *a);
+struct scm *lookup_binding (struct scm *name, struct scm *define_p);
+struct scm *lookup_value (struct scm *name);
 struct scm *make_builtin_type ();
-struct scm *make_bytes (char const *s, size_t length);
+struct scm *make_bytes (size_t length);
 struct scm *make_cell (long type, struct scm *car, struct scm *cdr);
 struct scm *make_pointer_cell (long type, long car, void *cdr);
 struct scm *make_value_cell (long type, long car, long cdr);
 struct scm *make_char (int n);
 struct scm *make_continuation (long n);
 struct scm *make_hash_table_ (long size);
-struct scm *make_hashq_type ();
+struct scm *make_hash_table_type ();
 struct scm *make_initial_module (struct scm *a);
 struct scm *make_macro (struct scm *name, struct scm *x);
 struct scm *make_number (long n);
@@ -153,14 +169,22 @@ struct scm *make_ref (struct scm *x);
 struct scm *make_string (char const *s, size_t length);
 struct scm *make_string0 (char const *s);
 struct scm *make_string_port (struct scm *x);
+struct scm *make_variable_type ();
 struct scm *make_vector_ (long k, struct scm *e);
 struct scm *mes_builtins (struct scm *a);
 struct scm *push_cc (struct scm *p1, struct scm *p2, struct scm *a, struct scm *c);
+struct scm *set_x (struct scm *x, struct scm *e, int define_p);
 struct scm *struct_ref_ (struct scm *x, long i);
 struct scm *struct_set_x_ (struct scm *x, long i, struct scm *e);
 struct scm *vector_ref_ (struct scm *x, long i);
 struct scm *vector_set_x_ (struct scm *x, long i, struct scm *e);
 FUNCTION builtin_function (struct scm *builtin);
+void assert_num (long pos, struct scm *x);
+void assert_range (int assert, long x);
+void assert_struct (long pos, struct scm *x);
+#if 0
+void assert_type (long type, char const *name_name, struct scm *x)
+#endif
 char *cell_bytes (struct scm *x);
 int peekchar ();
 int readchar ();
