@@ -43,6 +43,10 @@ int mknod (char const *file_name, mode_t mode, dev_t dev);
 int chown (char const *file_name, uid_t owner, gid_t group);
 int rmdir (char const *file_name);
 int stat (char const *file_name, struct stat *buf);
+int lstat (char const *file_name, struct stat *buf);
+mode_t umask (mode_t mask);
+int utimensat(int dirfd, char const *file_name,
+              struct timespec const *times, int flags);
 
 #define S_IFIFO 0010000
 #define S_IFCHR 0020000
