@@ -1,6 +1,7 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
  * Copyright © 2018,2019,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2021 W. J. van der Laan <laanwj@protonmail.com>
  *
  * This file is part of GNU Mes.
  *
@@ -20,10 +21,17 @@
 
 #include <linux/syscall.h>
 #include <arch/syscall.h>
+#include <fcntl.h>
 #include <sys/stat.h>
 
 int
 mkdir (char const *file_name, mode_t mode)
 {
+#if defined (SYS_mkdir)
   return _sys_call2 (SYS_mkdir, (long) file_name, (long) mode);
+#elif defined (SYS_mkdirat)
+  return _sys_call3 (SYS_mkdirat, AT_FDCWD, (long) file_name, (long) mode);
+#else
+#error No usable mkdir syscall
+#endif
 }
