@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -50,6 +50,11 @@ vsnprintf (char *str, size_t size, char const *format, va_list ap)
             c = *++p;
           }
         char pad = ' ';
+        if (c == ' ')
+          {
+            pad = c;
+            c = *p++;
+          }
         if (c == '0')
           {
             pad = c;
@@ -114,7 +119,7 @@ vsnprintf (char *str, size_t size, char const *format, va_list ap)
             {
               long d = va_arg (ap, long);
               int base = c == 'o' ? 8 : c == 'x' || c == 'X' ? 16 : 10;
-              char const *s = ntoab (d, base, c != 'u' && c != 'x' && c != 'X');
+              char *s = ntoab (d, base, c != 'u' && c != 'x' && c != 'X');
               if (c == 'X')
                 strupr (s);
               int length = strlen (s);
@@ -198,6 +203,55 @@ vsnprintf (char *str, size_t size, char const *format, va_list ap)
                 }
               break;
             }
+          case 'f':
+          case 'e':
+          case 'E':
+          case 'g':
+          case 'G':
+            {
+              double d = va_arg8 (ap, double);
+              char *s = dtoab (d, 10, 1);
+              if (c == 'E' || c == 'G')
+                strupr (s);
+              int length = strlen (s);
+              if (precision == -1)
+                precision = length;
+              if (!left_p)
+                {
+                  while (width-- > precision)
+                    {
+                      if (count < size)
+                        *str++ = pad;
+                      count++;
+                    }
+                  while (precision > length)
+                    {
+                      if (count < size)
+                        *str++ = ' ';
+                      precision--;
+                      width--;
+                      count++;
+                    }
+                }
+              while (*s)
+                {
+                  if (precision-- <= 0)
+                    break;
+                  width--;
+                  c = *s++;
+                  if (count < size)
+                    *str++ = c;
+                  count++;
+                }
+              while (width > 0)
+                {
+                  width--;
+                  if (count < size)
+                    *str++ = pad;
+                  count++;
+                }
+              break;
+            }
           case 'n':
             {
               int *n = va_arg (ap, int *);
