@@ -23,9 +23,10 @@
 void
 abort (void)
 {
-  if (raise (SIGABRT) < 0) { /* could not raise SIGABRT */
-    /* Fail in any way possible */
-    unsigned char* x = (unsigned char*) 0;
-    *x = 2;
-  }
+  if (raise (SIGABRT) < 0) /* could not raise SIGABRT */
+    {
+      /* Fail in any way possible */
+      unsigned char* x = (unsigned char*) 0;
+      *x = 2;
+    }
 }
