@@ -20,7 +20,9 @@
 (define mes %version)
 
 (define (defined? x)
-  (module-variable (current-module) x))
+  ((lambda (v)
+     (if v (if (eq? (variable-ref v) *undefined*) #f #t) #f))
+   (core:hashq-ref (initial-module) x #f)))
 
 (define (cond-expand-expander clauses)
   (if (defined? (car (car clauses)))
@@ -62,10 +64,10 @@
 
 (define (cons* . rest)
   (if (null? (cdr rest)) (car rest)
-      (cons (car rest) (core:apply cons* (cdr rest) (current-module)))))
+      (cons (car rest) (core:apply cons* (cdr rest) (current-environment)))))
 
 (define (apply f h . t)
-  (if (null? t) (core:apply f h (current-module))
+  (if (null? t) (core:apply f h (current-environment))
       (apply f (apply cons* (cons h t)))))
 
 (define (append . rest)
@@ -146,10 +148,10 @@
 
 (define (cons* . rest)
   (if (null? (cdr rest)) (car rest)
-      (cons (car rest) (core:apply cons* (cdr rest) (current-module)))))
+      (cons (car rest) (core:apply cons* (cdr rest) (current-environment)))))
 
 (define (apply f h . t)
-  (if (null? t) (core:apply f h (current-module))
+  (if (null? t) (core:apply f h (current-environment))
       (apply f (apply cons* (cons h t)))))
 
 (define (append . rest)
