@@ -62,8 +62,6 @@ init_symbols_ ()                  /*:((internal)) */
   cell_vm_begin_expand = init_symbol (g_symbol, TSPECIAL, "core:eval");
   cell_vm_begin_expand_eval = init_symbol (g_symbol, TSPECIAL, "*vm:begin-expand-eval*");
   cell_vm_begin_expand_macro = init_symbol (g_symbol, TSPECIAL, "*vm:begin-expand-macro*");
-  cell_vm_begin_expand_primitive_load = init_symbol (g_symbol, TSPECIAL, "*vm:core:begin-expand-primitive-load*");
-  cell_vm_begin_primitive_load = init_symbol (g_symbol, TSPECIAL, "*vm:core:begin-primitive-load*");
   cell_vm_begin_read_input_file = init_symbol (g_symbol, TSPECIAL, "*vm-begin-read-input-file*");
   cell_vm_call_with_current_continuation2 = init_symbol (g_symbol, TSPECIAL, "*vm-call-with-current-continuation2*");
   cell_vm_call_with_values2 = init_symbol (g_symbol, TSPECIAL, "*vm-call-with-values2*");
@@ -110,9 +108,7 @@ init_symbols_ ()                  /*:((internal)) */
   cell_symbol_sc_expander_alist = init_symbol (g_symbol, TSYMBOL, "*sc-expander-alist*");
   cell_symbol_call_with_values = init_symbol (g_symbol, TSYMBOL, "call-with-values");
   cell_symbol_call_with_current_continuation = init_symbol (g_symbol, TSYMBOL, "call-with-current-continuation");
-  cell_symbol_boot_module = init_symbol (g_symbol, TSYMBOL, "boot-module");
-  cell_symbol_current_module = init_symbol (g_symbol, TSYMBOL, "current-module");
-  cell_symbol_primitive_load = init_symbol (g_symbol, TSYMBOL, "primitive-load");
+  cell_symbol_current_environment = init_symbol (g_symbol, TSYMBOL, "current-environment");
   cell_symbol_car = init_symbol (g_symbol, TSYMBOL, "car");
   cell_symbol_cdr = init_symbol (g_symbol, TSYMBOL, "cdr");
   cell_symbol_not_a_number = init_symbol (g_symbol, TSYMBOL, "not-a-number");
@@ -127,7 +123,6 @@ init_symbols_ ()                  /*:((internal)) */
   cell_symbol_builtin = init_symbol (g_symbol, TSYMBOL, "<builtin>");
   cell_symbol_frame = init_symbol (g_symbol, TSYMBOL, "<frame>");
   cell_symbol_hashq_table = init_symbol (g_symbol, TSYMBOL, "<hashq-table>");
-  cell_symbol_module = init_symbol (g_symbol, TSYMBOL, "<module>");
   cell_symbol_procedure = init_symbol (g_symbol, TSYMBOL, "procedure");
   cell_symbol_record_type = init_symbol (g_symbol, TSYMBOL, "<record-type>");
   cell_symbol_size = init_symbol (g_symbol, TSYMBOL, "size");
@@ -140,6 +135,9 @@ init_symbols_ ()                  /*:((internal)) */
   cell_symbol_arch = init_symbol (g_symbol, TSYMBOL, "%arch");
   cell_symbol_pmatch_car = init_symbol (g_symbol, TSYMBOL, "pmatch-car");
   cell_symbol_pmatch_cdr = init_symbol (g_symbol, TSYMBOL, "pmatch-cdr");
+  cell_symbol_variable = init_symbol (g_symbol, TSYMBOL, "<variable>");
+  cell_symbol_standard_eval_closure = init_symbol (g_symbol, TSYMBOL, "standard-eval-closure");
+  cell_symbol_standard_interface_eval_closure = init_symbol (g_symbol, TSYMBOL, "standard-interface-eval-closure");
 
   cell_type_bytes = init_symbol (g_symbol, TSYMBOL, "<cell:bytes>");
   cell_type_char = init_symbol (g_symbol, TSYMBOL, "<cell:char>");
@@ -157,7 +155,7 @@ init_symbols_ ()                  /*:((internal)) */
   cell_type_struct = init_symbol (g_symbol, TSYMBOL, "<cell:struct>");
   cell_type_symbol = init_symbol (g_symbol, TSYMBOL, "<cell:symbol>");
   cell_type_values = init_symbol (g_symbol, TSYMBOL, "<cell:values>");
-  cell_type_variable = init_symbol (g_symbol, TSYMBOL, "<cell:variable>");
+  cell_type_binding = init_symbol (g_symbol, TSYMBOL, "<cell:binding>");
   cell_type_vector = init_symbol (g_symbol, TSYMBOL, "<cell:vector>");
   cell_type_broken_heart = init_symbol (g_symbol, TSYMBOL, "<cell:broken-heart>");
 
@@ -180,8 +178,7 @@ init_symbols ()                  /*:((internal)) */
 
   struct scm *a = cell_nil;
   a = acons (cell_symbol_call_with_values, cell_symbol_call_with_values, a);
-  a = acons (cell_symbol_boot_module, cell_symbol_boot_module, a);
-  a = acons (cell_symbol_current_module, cell_symbol_current_module, a);
+  a = acons (cell_symbol_current_environment, cell_symbol_current_environment, a);
 
   a = acons (cell_symbol_mes_version, make_string0 (MES_VERSION), a);
   a = acons (cell_symbol_mes_datadir, make_string0 (g_datadir), a);
@@ -201,10 +198,14 @@ init_symbols ()                  /*:((internal)) */
   a = acons (cell_type_struct, make_number (TSTRUCT), a);
   a = acons (cell_type_symbol, make_number (TSYMBOL), a);
   a = acons (cell_type_values, make_number (TVALUES), a);
-  a = acons (cell_type_variable, make_number (TVARIABLE), a);
+  a = acons (cell_type_binding, make_number (TBINDING), a);
   a = acons (cell_type_vector, make_number (TVECTOR), a);
   a = acons (cell_type_broken_heart, make_number (TBROKEN_HEART), a);
 
+  /* types */
+  a = acons (cstring_to_symbol ("hash-table-type"), scm_hash_table_type, a);
+
+  /* the closure */
   a = acons (cell_closure, a, a);
 
   return a;
